"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var app = require("tns-core-modules/application");
var types = require("tns-core-modules/utils/types");
var fs = require("tns-core-modules/file-system");
var observable_1 = require("tns-core-modules/data/observable");
var color_1 = require("tns-core-modules/color/color");
var common = require("../common");
var common_1 = require("../common");
var common_2 = require("../common");
exports.PageMode = common_2.PageMode;
exports.documentTitleProperty = common_2.documentTitleProperty;
var PSPDFKit = com.pspdfkit.PSPDFKit;
var PSPDFDocument = com.pspdfkit.document.PSPDFDocument;
var PdfActivityConfiguration = com.pspdfkit.configuration.activity.PdfActivityConfiguration;
var PdfConfiguration = com.pspdfkit.configuration.PdfConfiguration;
var Uri = android.net.Uri;
var PdfActivity = com.pspdfkit.ui.PdfActivity;
var DownloadJob = com.pspdfkit.document.download.DownloadJob;
var DownloadRequest = com.pspdfkit.document.download.DownloadRequest;
var DownloadSource = com.pspdfkit.document.download.source.DownloadSource;
var PdfFragment = com.pspdfkit.ui.PdfFragment;
var FormType = com.pspdfkit.forms.FormType;
var FRAGMENT_TAG = 'PSPDFKitFragmentTag';
var TNSPSPDFKit = (function () {
    function TNSPSPDFKit(licenseKey) {
        this.context = app.android.context;
        this.events = observable_1.fromObject({});
        PSPDFKit.initialize(app.android.context, licenseKey);
    }
    TNSPSPDFKit.prototype.initWorker = function () {
        var _this = this;
        if (global['TNS_WEBPACK']) {
            var WorkerScript = require('nativescript-worker-loader!./worker.js');
            this.worker = new WorkerScript();
        }
        else {
            this.worker = new Worker('./worker.js');
        }
        this.worker.onmessage = function (msg) {
            if (msg.data.status === 1) {
                _this.events.notify({
                    eventName: 'status',
                    object: observable_1.fromObject({ value: 'downloading' })
                });
            }
            else if (msg.data.status === 2 && msg.data.filePath) {
                _this.events.notify({
                    eventName: 'status',
                    object: observable_1.fromObject({ value: 'completed' })
                });
                PdfActivity.showDocument(app.android.context, android.net.Uri.fromFile(new java.io.File(msg.data.filePath)), _this.config);
            }
            if (msg.data.progress) {
                _this.events.notify({
                    eventName: 'progress',
                    object: observable_1.fromObject({ value: msg.data.progress })
                });
            }
        };
        this.worker.onerror = function (err) {
            _this.events.notify({
                eventName: 'status',
                object: observable_1.fromObject({ value: 'failed' })
            });
        };
    };
    TNSPSPDFKit.prototype.convert = function (src, outPut) {
        return new Promise(function (resolve, reject) { });
    };
    TNSPSPDFKit.prototype.display = function (documentName, options) {
        if (options === void 0) { options = {}; }
        this.initWorker();
        if (PSPDFKit.isInitialized()) {
            this.config = new PdfActivityConfiguration.Builder(app.android.context).build();
            if (options.backgroundColor) {
                this.config.backgroundColor = new color_1.Color(options.backgroundColor).android;
            }
            if (options.spreadFitting) {
                switch (options.spreadFitting) {
                    case 'fit':
                        this.config.fitMode(com.pspdfkit.configuration.page.PageFitMode.FIT_TO_WIDTH);
                        break;
                    case 'fill':
                        this.config.fitMode(com.pspdfkit.configuration.page.PageFitMode.FIT_TO_SCREEN);
                        break;
                }
            }
            if (options.thumbnailBar) {
                switch (options.thumbnailBar) {
                    case 'none':
                        this.config.setThumbnailBarMode(com.pspdfkit.configuration.activity.ThumbnailBarMode
                            .THUMBNAIL_BAR_MODE_NONE);
                        break;
                    case 'scrollable':
                        this.config.setThumbnailBarMode(com.pspdfkit.configuration.activity.ThumbnailBarMode
                            .THUMBNAIL_BAR_MODE_SCROLLABLE);
                        break;
                    default:
                        this.config.setThumbnailBarMode(com.pspdfkit.configuration.activity.ThumbnailBarMode
                            .THUMBNAIL_BAR_MODE_DEFAULT);
                        break;
                }
            }
            switch (options.pageMode) {
                case 'single':
                    this.config.layoutMode(com.pspdfkit.configuration.page.PageLayoutMode.SINGLE);
                    break;
                case 'double':
                    this.config.layoutMode(com.pspdfkit.configuration.page.PageLayoutMode.DOUBLE);
                    break;
                default:
                    this.config.layoutMode(com.pspdfkit.configuration.page.PageLayoutMode.AUTO);
                    break;
            }
            switch (options.scrollDirection) {
                case 'horizontal':
                    this.config.scrollDirection(com.pspdfkit.configuration.page.PageScrollDirection.HORIZONTAL);
                    break;
                default:
                    this.config.scrollDirection(com.pspdfkit.configuration.page.PageScrollDirection.VERTICAL);
                    break;
            }
            if (options.minZoom) {
                this.config.startZoomScale(new java.lang.Float(options.minZoom));
            }
            if (options.maxZoom) {
                this.config.maxZoomScale(new java.lang.Float(options.maxZoom));
            }
            var file = void 0;
            if (types.isString(documentName) && documentName.startsWith('~')) {
                file = new java.io.File(fs.path.join(fs.knownFolders.currentApp().path, documentName.replace('~', '')));
                PdfActivity.showDocument(app.android.context, android.net.Uri.fromFile(file), this.config);
            }
            else if (types.isString(documentName) && documentName.startsWith('/')) {
                file = new java.io.File(documentName);
                PdfActivity.showDocument(app.android.context, android.net.Uri.fromFile(file), this.config);
            }
            else if ((types.isString(documentName) && documentName.startsWith('http://')) ||
                documentName.startsWith('https://')) {
                this.downloadDocument(documentName);
            }
        }
    };
    TNSPSPDFKit.prototype.downloadDocument = function (src) {
        var tempPath = fs.path.join(fs.knownFolders.temp().path, +new Date() + ".pdf");
        if (!this.worker) {
            if (global['TNS_WEBPACK']) {
                var WorkerScript = require('nativescript-worker-loader!./worker.js');
                this.worker = new WorkerScript();
            }
            else {
                this.worker = new Worker('./worker.js');
            }
        }
        else {
            this.worker.postMessage({
                action: 'download',
                path: tempPath,
                url: src
            });
        }
    };
    return TNSPSPDFKit;
}());
exports.TNSPSPDFKit = TNSPSPDFKit;
var TNSPSPDFView = (function (_super) {
    __extends(TNSPSPDFView, _super);
    function TNSPSPDFView() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._formsEnabled = true;
        return _this;
    }
    TNSPSPDFView.toggleMemoryMode = function () { };
    TNSPSPDFView.prototype.clearCache = function () { };
    TNSPSPDFView.prototype.createNativeView = function () {
        var _this = this;
        this.config = new PdfConfiguration.Builder();
        if (this._formsEnabled) {
            this.config.enableFormEditing();
        }
        else {
            this.config.disableFormEditing();
        }
        if (this._backgroundColor) {
            this.config.backgroundColor = new color_1.Color(this._backgroundColor).android;
        }
        if (this._spreadFitting) {
            switch (this._spreadFitting) {
                case 'fit':
                    this.config.fitMode(com.pspdfkit.configuration.page.PageFitMode.FIT_TO_WIDTH);
                    break;
                case 'fill':
                    this.config.fitMode(com.pspdfkit.configuration.page.PageFitMode.FIT_TO_SCREEN);
                    break;
            }
        }
        switch (this._thumbnailBar) {
            case 'none':
                this.config.setThumbnailBarMode(com.pspdfkit.configuration.activity.ThumbnailBarMode
                    .THUMBNAIL_BAR_MODE_NONE);
                break;
            case 'scrollable':
                this.config.setThumbnailBarMode(com.pspdfkit.configuration.activity.ThumbnailBarMode
                    .THUMBNAIL_BAR_MODE_SCROLLABLE);
                break;
            default:
                this.config.setThumbnailBarMode(com.pspdfkit.configuration.activity.ThumbnailBarMode
                    .THUMBNAIL_BAR_MODE_DEFAULT);
                break;
        }
        if (this._pageMode) {
            switch (this._pageMode) {
                case common_1.PageMode.SINGLE:
                case 'single':
                    this.config.layoutMode(com.pspdfkit.configuration.page.PageLayoutMode.SINGLE);
                    break;
                case common_1.PageMode.DOUBLE:
                case 'double':
                    this.config.layoutMode(com.pspdfkit.configuration.page.PageLayoutMode.DOUBLE);
                    break;
                default:
                    this.config.layoutMode(com.pspdfkit.configuration.page.PageLayoutMode.AUTO);
                    break;
            }
        }
        if (this._scrollDirection) {
            switch (this._scrollDirection) {
                case 'horizontal':
                    this.config.scrollDirection(com.pspdfkit.configuration.page.PageScrollDirection.HORIZONTAL);
                    break;
                default:
                    this.config.scrollDirection(com.pspdfkit.configuration.page.PageScrollDirection.VERTICAL);
                    break;
            }
        }
        if (this._maximumZoomScale) {
            this.config.maxZoomScale(new java.lang.Float(this._maximumZoomScale));
        }
        if (global['TNS_WEBPACK']) {
            var WorkerScript = require('nativescript-worker-loader!./worker.js');
            this.worker = new WorkerScript();
        }
        else {
            this.worker = new Worker('./worker.js');
        }
        this.worker.onmessage = function (msg) {
            if (msg.data.status === 1) {
                _this.notify({
                    eventName: 'status',
                    object: observable_1.fromObject({ value: 'downloading' })
                });
            }
            else if (msg.data.status === 2 && msg.data.filePath) {
                _this.notify({
                    eventName: 'status',
                    object: observable_1.fromObject({ value: 'completed' })
                });
                _this.init(msg.data.filePath);
            }
            if (msg.data.progress) {
                _this.notify({
                    eventName: 'progress',
                    object: observable_1.fromObject({ value: msg.data.progress })
                });
            }
        };
        this.worker.onerror = function (err) {
            _this.notify({
                eventName: 'status',
                object: observable_1.fromObject({ value: 'failed' })
            });
        };
        this._layoutId = android.view.View.generateViewId();
        return new android.widget.LinearLayout(this._context);
    };
    TNSPSPDFView.prototype[common_1.documentTitleProperty.setNative] = function (title) {
        var doc = this._fragment ? this._fragment.getDocument() : null;
        if (types.isString(title) && doc) {
            var meta = doc.getMetadata();
            if (meta) {
                meta.set(com.pspdfkit.document.DocumentMetadata.PDF_METADATA_TITLE, title);
            }
        }
    };
    Object.defineProperty(TNSPSPDFView.prototype, "spreadFitting", {
        set: function (fit) { },
        enumerable: true,
        configurable: true
    });
    TNSPSPDFView.prototype.getPageIndex = function () {
        if (this._fragment) {
            return this._fragment.getPageIndex();
        }
        return 0;
    };
    TNSPSPDFView.prototype.setPageIndex = function (index, animated) {
        if (this._fragment) {
            this._fragment.setPageIndex(index, !!animated);
        }
    };
    TNSPSPDFView.prototype.getAnnotationField = function (name) {
        return;
    };
    TNSPSPDFView.prototype.getFormField = function (name) {
        if (this._fragment) {
            var field = this._fragment
                .getDocument()
                .getFormProvider()
                .getFormElementWithName(name);
            if (field) {
                return field.getText();
            }
        }
        return;
    };
    TNSPSPDFView.prototype.getAllFormFields = function () {
        var obj = {};
        var array = this._fragment
            .getDocument()
            .getFormProvider()
            .getFormFields();
        if (array) {
            var len = array.size();
            for (var i = 0; i < len; i++) {
                var item = array.get(i);
                switch (item.getType()) {
                    case FormType.RADIOBUTTON:
                    case FormType.CHECKBOX:
                        var checkField = item.getFormElement();
                        if (checkField.isSelected()) {
                            obj[item.getFullyQualifiedName()] = { value: true };
                        }
                        else {
                            obj[item.getFullyQualifiedName()] = { value: false };
                        }
                        break;
                    case FormType.LISTBOX:
                    case FormType.COMBOBOX:
                        var comboField = item.getFormElement();
                        var comboFieldOptions = comboField.getOptions();
                        var comboFieldSelectedArray = comboField.getSelectedIndexes();
                        var comboFieldSelectedArraySize = comboFieldSelectedArray.size();
                        if (comboFieldSelectedArraySize === 1) {
                            if (comboFieldSelectedArray.get(0)) {
                                var selectedIndex = Number(comboFieldSelectedArray.get(0));
                                if (comboFieldOptions.get(selectedIndex)) {
                                    obj[comboField.getFullyQualifiedName()] = {
                                        value: comboFieldOptions.get(selectedIndex).getValue()
                                    };
                                }
                                else {
                                    obj[comboField.getFullyQualifiedName()] = { value: '' };
                                }
                            }
                            else {
                                obj[comboField.getFullyQualifiedName()] = { value: '' };
                            }
                        }
                        else if (comboFieldSelectedArray > 1) {
                        }
                        break;
                    case FormType.SIGNATURE:
                        break;
                    case FormType.TEXT:
                        var textField = item.getFormElement();
                        obj[item.getFullyQualifiedName()] = { value: textField.getText() };
                        break;
                    default:
                        break;
                }
            }
        }
        return obj;
    };
    TNSPSPDFView.prototype.setFormField = function (name, value) {
        if (name && value) {
            var array = this._fragment
                .getDocument()
                .getFormProvider()
                .getFormFields();
            if (array) {
                var len = array.size();
                for (var i = 0; i < len; i++) {
                    var item = array.get(i);
                    if (item.getFullyQualifiedName() === name) {
                        switch (item.getType()) {
                            case FormType.RADIOBUTTON:
                            case FormType.PUSHBUTTON:
                            case FormType.CHECKBOX:
                                if (common.boolParse(value)) {
                                    item.select();
                                }
                                else {
                                    item.deselect();
                                }
                                break;
                            case FormType.COMBOBOX:
                            case FormType.LISTBOX:
                                var comboField = item.getFormElement();
                                var comboFieldOptions = comboField.getOptions();
                                var comboFieldSelectedArray = comboField.getSelectedIndexes();
                                var comboFieldSelectedArraySize = comboFieldSelectedArray.size();
                                if (comboFieldSelectedArraySize === 1) {
                                    if (comboFieldSelectedArray.get(0)) {
                                        var selectedIndex = Number(comboFieldSelectedArray.get(0));
                                        if (comboFieldOptions.get(selectedIndex)) {
                                            comboFieldOptions.get(selectedIndex).setValue(value);
                                        }
                                    }
                                }
                                else if (comboFieldSelectedArray > 1) {
                                }
                                break;
                            case FormType.SIGNATURE:
                                break;
                            case FormType.TEXT:
                                item.setText(value);
                                break;
                            default:
                                break;
                        }
                        break;
                    }
                }
            }
        }
    };
    TNSPSPDFView.prototype.setFormFields = function (obj) {
        var _this = this;
        Object.keys(obj).forEach(function (key, index) {
            var data = obj[key];
            var array = _this._fragment
                .getDocument()
                .getFormProvider()
                .getFormFields();
            if (array) {
                var len = array.size();
                for (var i = 0; i < len; i++) {
                    var item = array.get(i);
                    if (item.getFullyQualifiedName() === key) {
                        switch (item.getType()) {
                            case FormType.RADIOBUTTON:
                            case FormType.PUSHBUTTON:
                            case FormType.CHECKBOX:
                                var checkField = item.getFormElement();
                                if (common.boolParse(data['value'])) {
                                    checkField.select();
                                }
                                else {
                                    checkField.deselect();
                                }
                                break;
                            case FormType.COMBOBOX:
                            case FormType.LISTBOX:
                                var comboField = item.getFormElement();
                                var comboFieldOptions = comboField.getOptions();
                                var comboFieldOptionsSize = comboFieldOptions.size();
                                var comboFieldSelectedArray = comboField.getSelectedIndexes();
                                var comboFieldSelectedArraySize = comboFieldSelectedArray.size();
                                var list = new java.util.ArrayList();
                                for (var i_1 = 0; i_1 < comboFieldOptionsSize; i_1++) {
                                    var _item = comboFieldOptions.get(i_1);
                                    if (_item.getValue() === data['value']) {
                                        list.add(new java.lang.Integer(i_1));
                                        comboField.setSelectedIndexes(list);
                                        break;
                                    }
                                }
                                break;
                            case FormType.SIGNATURE:
                                break;
                            case FormType.TEXT:
                                item.getFormElement().setText(data['value']);
                                break;
                            default:
                                break;
                        }
                        break;
                    }
                }
            }
        });
    };
    Object.defineProperty(TNSPSPDFView.prototype, "scrollDirection", {
        set: function (direction) {
            this._scrollDirection = direction;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "maxZoom", {
        set: function (value) {
            this._maximumZoomScale = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "minZoom", {
        set: function (value) {
            this._minimumZoomScale = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "enableFormElementsZoom", {
        set: function (value) {
            this._formElementZoomEnabled = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "searchResultZoom", {
        set: function (value) {
            this._searchResultZoomScale = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "pageMode", {
        set: function (value) {
            this._pageMode = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "backgroundColor", {
        set: function (value) {
            this._backgroundColor = value;
        },
        enumerable: true,
        configurable: true
    });
    TNSPSPDFView.prototype.initNativeView = function () {
        if (this._fragment) {
            var ref_1 = new WeakRef(this);
            var listener = new com.pspdfkit.listeners.DocumentListener({
                onPageUpdated: function (document, pageIndex) { },
                onPageChanged: function (document, pageIndex) {
                    var owner = ref_1.get();
                    owner.selectedIndex = pageIndex;
                },
                onDocumentLoaded: function (document) { },
                onDocumentZoomed: function (document, ageIndex, scaleFactor) { }
            });
            this._fragment.addDocumentListener(listener);
        }
        this.nativeView.setId(this._layoutId);
    };
    TNSPSPDFView.prototype.disposeNativeView = function () {
        _super.prototype.disposeNativeView.call(this);
    };
    Object.defineProperty(TNSPSPDFView.prototype, "formsEnabled", {
        get: function () {
            return this._formsEnabled;
        },
        set: function (enabled) {
            this._formsEnabled = enabled;
        },
        enumerable: true,
        configurable: true
    });
    TNSPSPDFView.prototype.init = function (documentName) {
        var file;
        var uri;
        if (documentName.startsWith('~')) {
            file = new java.io.File(fs.path.join(fs.knownFolders.currentApp().path, documentName.replace('~', '')));
        }
        else if (types.isString(documentName) && documentName.startsWith('/')) {
            file = new java.io.File(documentName);
        }
        else if (types.isString(documentName) &&
            documentName.startsWith('file:')) {
            file = new java.io.File(documentName);
        }
        uri = android.net.Uri.fromFile(file);
        var manager = app.android.foregroundActivity.getSupportFragmentManager();
        this._fragment = com.pspdfkit.ui.PdfFragment.newInstance(uri, this.config.build());
        if (this._fragment) {
            var ref_2 = new WeakRef(this);
            var listener = new com.pspdfkit.listeners.DocumentListener({
                onPageUpdated: function (document, pageIndex) { },
                onPageChanged: function (document, pageIndex) {
                    var owner = ref_2.get();
                    owner.selectedIndex = pageIndex;
                },
                onDocumentLoaded: function (document) { },
                onDocumentZoomed: function (document, ageIndex, scaleFactor) { }
            });
            this._fragment.addDocumentListener(listener);
        }
        if (manager) {
            manager
                .beginTransaction()
                .replace(this._layoutId, this._fragment, FRAGMENT_TAG)
                .commit();
        }
    };
    TNSPSPDFView.prototype[common.srcProperty.setNative] = function (src) {
        if (src.startsWith('http')) {
            this.downloadDocument(src);
        }
        else {
            this.init(src);
        }
    };
    TNSPSPDFView.prototype.onLoaded = function () {
        _super.prototype.onLoaded.call(this);
        if (this._initialLoad && this._fragment && this._fragment.isDetached()) {
            var manager = app.android.foregroundActivity.getSupportFragmentManager();
            manager
                .beginTransaction()
                .attach(this._fragment)
                .commit();
        }
        this._initialLoad = true;
    };
    TNSPSPDFView.prototype.onUnloaded = function () {
        _super.prototype.onUnloaded.call(this);
        if (this._initialLoad && this._fragment && !this._fragment.isDetached()) {
            var manager = app.android &&
                app.android.foregroundActivity &&
                typeof app.android.foregroundActivity.getSupportFragmentManager() ===
                    'function'
                ? app.android.foregroundActivity.getSupportFragmentManager()
                : null;
            if (!manager)
                return;
            manager
                .beginTransaction()
                .detach(this._fragment)
                .commit();
        }
    };
    TNSPSPDFView.prototype.downloadDocument = function (src) {
        var tempPath = fs.path.join(fs.knownFolders.temp().path, +new Date() + ".pdf");
        if (!this.worker) {
            if (global['TNS_WEBPACK']) {
                var WorkerScript = require('nativescript-worker-loader!./worker.js');
                this.worker = new WorkerScript();
            }
            else {
                this.worker = new Worker('./worker.js');
            }
        }
        else {
            this.worker.postMessage({
                action: 'download',
                path: tempPath,
                url: src
            });
        }
    };
    return TNSPSPDFView;
}(common.TNSPSPDFView));
exports.TNSPSPDFView = TNSPSPDFView;
//# sourceMappingURL=pspdfkit.js.map