"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var frame_1 = require("tns-core-modules/ui/frame");
var view_1 = require("tns-core-modules/ui/core/view");
var fs = require("tns-core-modules/file-system");
var common = require("../common");
var observable_1 = require("tns-core-modules/data/observable");
var utils = require("tns-core-modules/utils/utils");
var types = require("tns-core-modules/utils/types");
var color_1 = require("tns-core-modules/color");
var common_1 = require("../common");
var common_2 = require("../common");
exports.PageMode = common_2.PageMode;
exports.documentTitleProperty = common_2.documentTitleProperty;
exports.PROGRESS_EVENT = 'progress';
var main_queue = dispatch_get_current_queue();
var TNSPSPDFKit = (function () {
    function TNSPSPDFKit(licenseKey) {
        this.events = observable_1.fromObject({});
        PSPDFKit.setLicenseKey(licenseKey);
    }
    TNSPSPDFKit.prototype.convert = function (src, outPut) {
        if (!outPut) {
            outPut = "file://" + fs.path.join(fs.knownFolders.documents().path, +new Date() + '.pdf');
        }
        else {
            if (outPut.startsWith('/')) {
                outPut = "file://" + outPut;
            }
            if (outPut.startsWith('file:')) {
                outPut = encodeURI(outPut);
            }
        }
        if (src.startsWith('~/')) {
            src = 'file://' + src.replace('~', '');
        }
        if (src.startsWith('file:')) {
            src = encodeURI(src);
        }
        return new Promise(function (resolve, reject) {
            var main_queue = dispatch_get_current_queue();
            dispatch_async(main_queue, function () {
                if (src.startsWith('file') || src.startsWith('http')) {
                    PSPDFProcessor.generatePDFFromURLOutputFileURLOptionsCompletionBlock(NSURL.URLWithString(src), NSURL.URLWithString(outPut), null, function (url, error) {
                        if (!error) {
                            resolve(outPut);
                        }
                        else {
                            reject(error.localizedDescription);
                        }
                    });
                }
                else {
                    PSPDFProcessor.generatePDFFromHTMLStringOutputFileURLOptionsCompletionBlock(src, NSURL.URLWithString(outPut), null, function (error) {
                        if (!error) {
                            resolve(outPut);
                        }
                        else {
                            reject(error.localizedDescription);
                        }
                    });
                }
            });
        });
    };
    TNSPSPDFKit.prototype.display = function (documentName, options) {
        if (options === void 0) { options = {}; }
        var controller = PSPDFViewController.new();
        if (options.backgroundColor) {
            controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                config.backgroundColor = new color_1.Color(options.backgroundColor).ios;
            });
        }
        switch (options.scrollDirection) {
            case 'horizontal':
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.scrollDirection = PSPDFScrollDirection.Horizontal;
                });
                break;
            default:
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.scrollDirection = PSPDFScrollDirection.Vertical;
                });
                break;
        }
        switch (options.spreadFitting) {
            case 'fit':
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.spreadFitting = PSPDFConfigurationSpreadFitting.Fit;
                });
                break;
            case 'fill':
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.spreadFitting = PSPDFConfigurationSpreadFitting.Fill;
                });
                break;
            default:
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.spreadFitting = PSPDFConfigurationSpreadFitting.Adaptive;
                });
                break;
        }
        switch (options.thumbnailBar) {
            case 'scrollable':
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.thumbnailBarMode = PSPDFThumbnailBarMode.Scrollable;
                });
                break;
            case 'scrubber':
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.thumbnailBarMode = PSPDFThumbnailBarMode.ScrubberBar;
                });
                break;
            case 'none':
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.thumbnailBarMode = PSPDFThumbnailBarMode.None;
                });
                break;
        }
        switch (options.scrubberBar) {
            case 'verticalRight':
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.scrubberBarType = PSPDFScrubberBarType.VerticalRight;
                });
                break;
            case 'verticalLeft':
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.scrubberBarType = PSPDFScrubberBarType.VerticalLeft;
                });
                break;
            default:
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.scrubberBarType = PSPDFScrubberBarType.Horizontal;
                });
                break;
        }
        if (options.thumbnailSize) {
            var sizes_1 = options.thumbnailSize.split(' ');
            if (sizes_1.length === 2) {
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.thumbnailSize = CGSizeMake(parseInt(sizes_1[0], 10), parseInt(sizes_1[1], 10));
                });
            }
            else {
                controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.thumbnailSize = CGSizeMake(parseInt(options.thumbnailSize, 10), parseInt(options.thumbnailSize, 10));
                });
            }
        }
        controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
            config.maximumZoomScale = options.maxZoom;
        });
        controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
            config.minimumZoomScale = options.minZoom;
        });
        if (types.isString(documentName) && documentName.startsWith('~')) {
            controller.document = getDocument(documentName);
            frame_1.topmost().ios.controller.initWithRootViewController(controller);
        }
        else if (types.isString(documentName) && documentName.startsWith('/')) {
            controller.document = getDocument(documentName);
            frame_1.topmost().ios.controller.initWithRootViewController(controller);
        }
        else if (types.isString(documentName) &&
            documentName.startsWith('file:')) {
            controller.document = getDocument(documentName);
            frame_1.topmost().ios.controller.initWithRootViewController(controller);
        }
        else if (types.isString(documentName) &&
            documentName.startsWith('http')) {
            this.downloadDocument(documentName);
        }
    };
    TNSPSPDFKit.prototype.downloadDocument = function (src) {
        var _this = this;
        var url = NSString.stringWithString(src);
        var parts = url.componentsSeparatedByString('/');
        var filename = parts.lastObject;
        var tempPath = fs.knownFolders.temp().path;
        var fullPath = fs.path.join(tempPath, filename);
        var configuration = NSURLSessionConfiguration.defaultSessionConfiguration;
        var manager = AFURLSessionManager.alloc().initWithSessionConfiguration(configuration);
        var URL = NSURL.URLWithString(src);
        var request = NSURLRequest.requestWithURL(URL);
        this._downloadTask = manager.downloadTaskWithRequestProgressDestinationCompletionHandler(request, function (progress) {
            dispatch_async(main_queue, function () {
                if (_this._downloadTask &&
                    _this._downloadTask.state === 0) {
                    if (Math.floor(Math.round(progress.fractionCompleted * 100)) >
                        _this._progress) {
                        _this._progress = Math.floor(Math.round(progress.fractionCompleted * 100));
                        _this.events.notify({
                            eventName: exports.PROGRESS_EVENT,
                            object: observable_1.fromObject({
                                value: Math.floor(Math.round(progress.fractionCompleted * 100))
                            })
                        });
                    }
                }
            });
        }, function (targetPath, response) {
            return NSURL.fileURLWithPath(fullPath);
        }, function (response, filePath, error) {
            if (error) {
                _this.events.notify({
                    eventName: 'status',
                    object: observable_1.fromObject({
                        value: 'error',
                        msg: error.localizedDescription,
                        message: error.localizedDescription
                    })
                });
            }
            else {
                if (_this._downloadTask &&
                    _this._downloadTask.state === 3 &&
                    !_this._downloadTask.error) {
                    var controller = PSPDFViewController.new();
                    controller.document = getDocument(filePath.path);
                    frame_1.topmost().ios.controller.initWithRootViewController(controller);
                    _this.events.notify({
                        eventName: 'status',
                        object: observable_1.fromObject({ value: 'completed' })
                    });
                }
            }
        });
        this._downloadTask.resume();
        this.events.notify({
            eventName: 'status',
            object: observable_1.fromObject({ value: 'downloading' })
        });
    };
    return TNSPSPDFKit;
}());
exports.TNSPSPDFKit = TNSPSPDFKit;
var TNSPSPDFView = (function (_super) {
    __extends(TNSPSPDFView, _super);
    function TNSPSPDFView() {
        var _this = _super.call(this) || this;
        _this.currentSize = CGSizeZero;
        _this._progress = 0;
        _this.controller = PSPDFViewController.new();
        _this.nativeView = _this.nativeViewProtected = UIView.new();
        _this.backgroundColor = '#fff';
        return _this;
    }
    TNSPSPDFView.prototype[common_1.documentTitleProperty.setNative] = function (title) {
        if (types.isString(title) && this.controller && this.controller.document) {
            this.controller.document.title = title;
        }
    };
    TNSPSPDFView.prototype.addObserver = function () {
        if (this._observer) {
            this.removeObserver();
        }
        var center = utils.ios.getter(NSNotificationCenter, NSNotificationCenter.defaultCenter);
        var queue = utils.ios.getter(NSOperationQueue, NSOperationQueue.mainQueue);
        var ref = new WeakRef(this);
        this._observer = center.addObserverForNameObjectQueueUsingBlock(PSPDFDocumentViewControllerSpreadIndexDidChangeNotification, null, queue, function (notification) {
            var owner = ref.get();
            if (owner != null) {
                owner.selectedIndex = notification.object.spreadIndex;
            }
        });
    };
    TNSPSPDFView.prototype.removeObserver = function () {
        if (this._observer) {
            var center = utils.ios.getter(NSNotificationCenter, NSNotificationCenter.defaultCenter);
            center.removeObserver(this._observer);
        }
    };
    TNSPSPDFView.toggleMemoryMode = function () {
        var instance = utils.ios.getter(PSPDFKit, PSPDFKit.sharedInstance);
        if (instance.valueForKey('com.pspdfkit.low-memory-mode')) {
            instance.setValueForKey(false, 'com.pspdfkit.low-memory-mode');
        }
        else {
            instance.setValueForKey(true, 'com.pspdfkit.low-memory-mode');
        }
    };
    TNSPSPDFView.prototype.initNativeView = function () {
        if (this.src) {
            if (this.src.startsWith('http')) {
                this.downloadDocument(this.src);
            }
            else {
                this.controller.document = getDocument(this.src);
                this.setupView();
            }
        }
    };
    TNSPSPDFView.prototype.clearCache = function () {
        if (this.controller && this.controller.document) {
            this.controller.document.clearCache();
        }
    };
    TNSPSPDFView.prototype.setupView = function () {
        this.removeObserver();
        this.addObserver();
        if (!this._isSetup) {
            this._isSetup = true;
            this.controller.view.autoresizingMask =
                2 | 16;
            var parent_1 = frame_1.topmost().ios.controller.visibleViewController;
            parent_1.addChildViewController(this.controller);
            this.controller.view.frame = this.nativeView.bounds;
            this.nativeView.addSubview(this.controller.view);
            this.controller.didMoveToParentViewController(parent_1);
        }
    };
    TNSPSPDFView.prototype.onLoaded = function () {
        _super.prototype.onLoaded.call(this);
        this.addObserver();
    };
    TNSPSPDFView.prototype.onUnloaded = function () {
        this.removeObserver();
        _super.prototype.onUnloaded.call(this);
    };
    TNSPSPDFView.prototype.disposeNativeView = function () {
        if (this._downloadTask) {
            this._downloadTask.cancel();
        }
        this.controller.willMoveToParentViewController(null);
        if (this.controller.view) {
            this.controller.view.removeFromSuperview();
        }
        this.controller.removeFromParentViewController();
        this._downloadTask = null;
        this.controller = null;
        _super.prototype.disposeNativeView.call(this);
    };
    TNSPSPDFView.prototype.onMeasure = function (widthMeasureSpec, heightMeasureSpec) {
        var nativeView = this.nativeView;
        if (nativeView) {
            var width = view_1.layout.getMeasureSpecSize(widthMeasureSpec);
            var height = view_1.layout.getMeasureSpecSize(heightMeasureSpec);
            this.setMeasuredDimension(width, height);
        }
    };
    Object.defineProperty(TNSPSPDFView.prototype, "backgroundColor", {
        set: function (value) {
            this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                config.backgroundColor = new color_1.Color(value).ios;
            });
        },
        enumerable: true,
        configurable: true
    });
    TNSPSPDFView.prototype[common.srcProperty.setNative] = function (src) {
        if (src.startsWith('http')) {
            this.downloadDocument(src);
        }
        else if (this.controller) {
            this.controller.document = getDocument(src);
            if (types.isString(this.documentTitle) &&
                this.controller &&
                this.controller.document) {
                this.controller.document.title = this.documentTitle;
            }
            this.setupView();
        }
    };
    TNSPSPDFView.prototype.getPageIndex = function () {
        if (this.controller) {
            return this.controller.pageIndex;
        }
        return 0;
    };
    TNSPSPDFView.prototype.setPageIndex = function (index, animated) {
        if (this.controller) {
            this.controller.setPageIndexAnimated(index, !!animated);
        }
    };
    TNSPSPDFView.prototype.getAnnotationField = function (name) {
        if (this.controller && this.controller.document) {
            var field = this.controller.document.formParser.findAnnotationWithFieldName(name);
            if (field) {
                return field.exportValue;
            }
            else {
                return;
            }
        }
        return;
    };
    TNSPSPDFView.prototype.getFormField = function (name) {
        if (this.controller && this.controller.document) {
            var field = this.controller.document.formParser.findFieldWithFullFieldName(name);
            if (field) {
                return field.exportValue;
            }
            else {
                return;
            }
        }
        return;
    };
    TNSPSPDFView.prototype.getAllFormFields = function () {
        var array = this.controller.document.formParser.formFields;
        var obj = {};
        var len = array.count;
        for (var i = 0; i < len; i++) {
            var item = array.objectAtIndex(i);
            obj[item.fullyQualifiedName] = { value: item.value };
        }
        return obj;
    };
    TNSPSPDFView.prototype.setFormField = function (name, value) {
        if (name && value) {
            var array = this.controller.document.formParser.formFields;
            var len = array.count;
            for (var i = 0; i < len; i++) {
                var item = array.objectAtIndex(i);
                if (item.fullyQualifiedName === name) {
                    if (types.isBoolean(value)) {
                        switch (value) {
                            case true:
                                item.value = 'YES';
                                break;
                            default:
                                item.value = 'NO';
                                break;
                        }
                    }
                    else {
                        item.value = value;
                    }
                    break;
                }
            }
        }
    };
    Object.defineProperty(TNSPSPDFView.prototype, "undoEnabled", {
        set: function (enabled) {
            if (this.controller && this.controller.document) {
                this.controller.document.undoEnabled = enabled;
            }
        },
        enumerable: true,
        configurable: true
    });
    TNSPSPDFView.prototype.setFormFields = function (obj) {
        var arr = this.controller.document.formParser.formFields;
        var len = arr.count;
        Object.keys(obj).forEach(function (key, index) {
            var item = obj[key];
            for (var i = 0; i < len; i++) {
                var field = arr.objectAtIndex(i);
                if (field.fullyQualifiedName === key) {
                    if (types.isBoolean(item['value'])) {
                        switch (item['value']) {
                            case true:
                                field.value = 'YES';
                                break;
                            default:
                                field.value = 'NO';
                                break;
                        }
                    }
                    else {
                        field.value = item['value'];
                    }
                    break;
                }
            }
        });
    };
    Object.defineProperty(TNSPSPDFView.prototype, "backgroundSaving", {
        set: function (enabled) {
            this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                config.allowBackgroundSaving = enabled;
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "formsEnabled", {
        get: function () {
            if (this.controller && this.controller.document) {
                return this.controller.document.formsEnabled;
            }
            return false;
        },
        set: function (enabled) {
            if (this.controller && this.controller.document) {
                this.controller.document.formsEnabled = enabled;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "scrollDirection", {
        set: function (direction) {
            switch (direction) {
                case 'horizontal':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.scrollDirection = PSPDFScrollDirection.Horizontal;
                    });
                    break;
                default:
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.scrollDirection = PSPDFScrollDirection.Vertical;
                    });
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "spreadFitting", {
        set: function (fit) {
            switch (fit) {
                case 'fit':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.spreadFitting = PSPDFConfigurationSpreadFitting.Fit;
                    });
                    break;
                case 'fill':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.spreadFitting = PSPDFConfigurationSpreadFitting.Fill;
                    });
                    break;
                default:
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.spreadFitting = PSPDFConfigurationSpreadFitting.Adaptive;
                    });
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "thumbnailBar", {
        set: function (bar) {
            switch (bar) {
                case 'scrollable':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.thumbnailBarMode = PSPDFThumbnailBarMode.Scrollable;
                    });
                    break;
                case 'scrubber':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.thumbnailBarMode = PSPDFThumbnailBarMode.ScrubberBar;
                    });
                    break;
                default:
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.thumbnailBarMode = PSPDFThumbnailBarMode.None;
                    });
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "scrubberBar", {
        set: function (bar) {
            switch (bar) {
                case 'verticalRight':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.scrubberBarType = PSPDFScrubberBarType.VerticalRight;
                    });
                    break;
                case 'verticalLeft':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.scrubberBarType = PSPDFScrubberBarType.VerticalLeft;
                    });
                    break;
                default:
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.scrubberBarType = PSPDFScrubberBarType.Horizontal;
                    });
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "thumbnailSize", {
        set: function (size) {
            var sizes = size.split(' ');
            if (sizes.length === 2) {
                this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.thumbnailSize = CGSizeMake(parseInt(sizes[0], 10), parseInt(sizes[1], 10));
                });
            }
            else {
                this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                    config.thumbnailSize = CGSizeMake(parseInt(size, 10), parseInt(size, 10));
                });
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "maxZoom", {
        set: function (value) {
            this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                config.maximumZoomScale = value;
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "minZoom", {
        set: function (value) {
            this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                config.minimumZoomScale = value;
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "enableFormElementsZoom", {
        set: function (value) {
            this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                config.formElementZoomEnabled = value;
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "searchResultZoom", {
        set: function (value) {
            this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                config.searchResultZoomScale = value;
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TNSPSPDFView.prototype, "pageMode", {
        set: function (value) {
            switch (value) {
                case common_1.PageMode.SINGLE:
                case 'single':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.pageMode = PSPDFPageMode.Single;
                    });
                    break;
                case common_1.PageMode.DOUBLE:
                case 'double':
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.pageMode = PSPDFPageMode.Double;
                    });
                    break;
                default:
                    this.controller.updateConfigurationWithoutReloadingWithBuilder(function (config) {
                        config.pageMode = PSPDFPageMode.Automatic;
                    });
                    break;
            }
        },
        enumerable: true,
        configurable: true
    });
    TNSPSPDFView.prototype.downloadDocument = function (src) {
        var _this = this;
        var url = NSString.stringWithString(src);
        var parts = url.componentsSeparatedByString('/');
        var filename = parts.lastObject;
        var tempPath = fs.knownFolders.temp().path;
        var fullPath = fs.path.join(tempPath, filename);
        var configuration = NSURLSessionConfiguration.defaultSessionConfiguration;
        var manager = AFURLSessionManager.alloc().initWithSessionConfiguration(configuration);
        var URL = NSURL.URLWithString(src);
        var request = NSURLRequest.requestWithURL(URL);
        this._downloadTask = manager.downloadTaskWithRequestProgressDestinationCompletionHandler(request, function (progress) {
            dispatch_async(main_queue, function () {
                if (_this._downloadTask &&
                    _this._downloadTask.state === 0) {
                    if (Math.floor(Math.round(progress.fractionCompleted * 100)) >
                        _this._progress) {
                        _this._progress = Math.floor(Math.round(progress.fractionCompleted * 100));
                        _this.notify({
                            eventName: exports.PROGRESS_EVENT,
                            object: observable_1.fromObject({
                                value: Math.floor(Math.round(progress.fractionCompleted * 100))
                            })
                        });
                    }
                }
            });
        }, function (targetPath, response) {
            return NSURL.fileURLWithPath(fullPath);
        }, function (response, filePath, error) {
            if (error) {
                _this.notify({
                    eventName: 'status',
                    object: observable_1.fromObject({
                        value: 'error',
                        msg: error.localizedDescription,
                        message: error.localizedDescription
                    })
                });
            }
            else {
                if (_this._downloadTask &&
                    _this._downloadTask.state === 3 &&
                    !_this._downloadTask.error) {
                    _this.controller.document = getDocument(filePath.path);
                    if (types.isString(_this.documentTitle) &&
                        _this.controller &&
                        _this.controller.document) {
                        _this.controller.document.title = _this.documentTitle;
                    }
                    _this.setupView();
                    _this.notify({
                        eventName: 'status',
                        object: observable_1.fromObject({ value: 'completed' })
                    });
                }
            }
        });
        this._downloadTask.resume();
        this.notify({
            eventName: 'status',
            object: observable_1.fromObject({ value: 'downloading' })
        });
    };
    return TNSPSPDFView;
}(common.TNSPSPDFView));
exports.TNSPSPDFView = TNSPSPDFView;
function getDocument(src) {
    var fileUrl;
    var document;
    if (src.startsWith('~')) {
        fileUrl = fs.path.join(fs.knownFolders.currentApp().path, src.replace('~', ''));
        document = PSPDFDocument.alloc().initWithURL(NSURL.fileURLWithPath(fileUrl));
    }
    else if (src.startsWith('/')) {
        document = PSPDFDocument.alloc().initWithURL(NSURL.fileURLWithPath(src));
    }
    else if (src.startsWith('file')) {
        document = PSPDFDocument.alloc().initWithURL(NSURL.URLWithString(encodeURI(src)));
    }
    return document;
}
//# sourceMappingURL=pspdfkit.js.map